pub struct ContentSearcher { /* private fields */ }Implementations
Sourceimpl ContentSearcher
impl ContentSearcher
pub fn new(lb: &Lb) -> Self
Sourcepub fn update_filter(&mut self, filter: Option<SearchFilter>)
pub fn update_filter(&mut self, filter: Option<SearchFilter>)
Update the active filter and refresh results for the current query.
Sourcepub fn results(&self) -> &[SearchResult]
pub fn results(&self) -> &[SearchResult]
Get search results.
Sourcepub fn build_time(&self) -> Duration
pub fn build_time(&self) -> Duration
How long it took to build the search index.