pub enum RecvError {
Closed,
Lagged(u64),
}Variants
Closed
There are no more active senders implying no further messages will ever be sent.
Lagged(u64)
The receiver lagged too far behind. Attempting to receive again will return the oldest message still retained by the channel.
Includes the number of skipped messages.